<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fo="http://www.w3.org/1999/XSL/Format"
    exclude-result-prefixes="xs" version="2.0">

    <xsl:output method="xml" encoding="utf-8"/>


    <xsl:template match="/">
        <fo:root>

            <fo:layout-master-set>
                <fo:simple-page-master master-name="my-page" page-width="7.5in" page-height="10in"
                    margin-top="0.5in" margin-bottom="0.5in" margin-left="0.5in"
                    margin-right="0.5in">
                    <fo:region-body region-name="xsl-region-body"/>
                    <fo:region-after extent="0.2in" region-name="xsl-region-footer"/>
                </fo:simple-page-master>
            </fo:layout-master-set>



            <fo:page-sequence master-reference="my-page">
                <xsl:call-template name="generate-footer"/>
                <fo:flow flow-name="xsl-region-body" font="12pt helvetica">

                    <fo:block font-weight="bold" font-size="125%"> ASIS&amp;T Student Chapters
                        (Partial List) </fo:block>
                    <xsl:for-each select="chapters/chapter">
                        <xsl:sort select="chapterName"/>
                        <fo:block space-before="0.125in" space-after="0.125in"
                            keep-together="always">
                            <fo:block font-weight="bold">
                                <xsl:value-of select="chapterName"/>
                            </fo:block>
                            <xsl:for-each select="advisor">
                                <fo:block> Advisor: <xsl:value-of select="name"/>
                                    <xsl:if test="email">
                                        <xsl:text> (</xsl:text>
                                        <xsl:value-of select="email"/>
                                        <xsl:text>)</xsl:text>
                                    </xsl:if>
                                </fo:block>
                            </xsl:for-each>

                            <xsl:for-each select="alternateAdvisor">
                                <fo:block> Alternate Advisor: <xsl:value-of select="name"/>
                                    <xsl:if test="email">
                                        <xsl:text> (</xsl:text>
                                        <xsl:value-of select="email"/>
                                        <xsl:text>)</xsl:text>
                                    </xsl:if>
                                </fo:block>
                            </xsl:for-each>

                            <fo:block> School Web: <fo:inline color="blue"><xsl:value-of
                                        select="schoolWebURL"/>
                                </fo:inline>
                            </fo:block>
                            <xsl:if test="chapterWebURL">
                                <fo:block> Chapter Web: <fo:inline color="blue"><xsl:value-of
                                            select="chapterWebURL"/></fo:inline>
                                </fo:block>
                            </xsl:if>
                        </fo:block>

                    </xsl:for-each>
                    <fo:block space-before="0.5in" font-size="80%"> Content current as of
                            <xsl:value-of select="/chapters/@asOf"/>
                        <xsl:text>.</xsl:text>
                    </fo:block>

                </fo:flow>
            </fo:page-sequence>
        </fo:root>
    </xsl:template>

    <xsl:template name="generate-footer">
        <fo:static-content flow-name="xsl-region-footer">
            <fo:block font="9pt helvetica" font-style="italic">
                <fo:table>
                    <fo:table-column column-width="50%"/>
                    <fo:table-column column-width="50%"/>
                    <fo:table-body>
                        <fo:table-row>
                            <fo:table-cell >
                                <fo:block text-align="start"> ASIS&amp;T Student Chapters (Partial List) </fo:block>
                            </fo:table-cell>
                            <fo:table-cell>
                                <fo:block text-align="end">
                                    <fo:page-number/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>
                    </fo:table-body>
                </fo:table>
            </fo:block>
        </fo:static-content>
    </xsl:template>





</xsl:stylesheet>
